"""MNE testing dataset."""

from ._testing import (data_path, requires_testing_data, get_version,
                       _pytest_param, _pytest_mark)
